EmailAccountLoginException class abstract

Exception to be thrown if the login via email/password fails.

Inspect the reason to determine whether this was due to invalid or unknown credentials, or whether the client has been blocked outright.

Implemented types

Constructors

EmailAccountLoginException({required EmailAccountLoginExceptionReason reason})
factory
EmailAccountLoginException.fromJson(Map<String, dynamic> jsonSerialization)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
reason EmailAccountLoginExceptionReason
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({EmailAccountLoginExceptionReason? reason}) EmailAccountLoginException
Returns a shallow copy of this EmailAccountLoginException with some or all fields replaced by the given arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a serialized JSON structure of the model which also includes fields used by the database.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited