EndpointAnonymousIdpBase class abstract Endpoint

Base endpoint for anonymous accounts.

Inheritance

Properties

caller → EndpointCaller
Holds a reference to the caller class.
finalinherited
client ↔ ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the endpoint this reference is connected to.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

login({String? token}) → Future<AuthSuccess>
Creates a new anonymous account and returns its session.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited