callStreamingServerEndpoint<T, G> abstract method

dynamic callStreamingServerEndpoint<T, G>(
  1. String endpoint,
  2. String method,
  3. Map<String, dynamic> args,
  4. Map<String, Stream> streams, {
  5. bool authenticated = true,
})

Calls a server endpoint method that supports streaming. The streams parameter is a map of stream names to stream objects. The method will listen to the streams and send the data to the server. Typically, this method is called by generated code.

T is the type of the return value of the endpoint stream. This is either a Stream or a Future.

G is the generic of T, such as T<G>.

If T is not a Stream or a Future, the method will throw an exception.

Implementation

dynamic callStreamingServerEndpoint<T, G>(
  String endpoint,
  String method,
  Map<String, dynamic> args,
  Map<String, Stream> streams, {
  bool authenticated = true,
});