EndpointIdpBase class abstract Endpoint

Base endpoint for identity providers.

Inheritance
Implementers

Constructors

EndpointIdpBase(EndpointCaller caller)

Properties

caller → EndpointCaller
Holds a reference to the caller class.
finalinherited
client ↔ ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the endpoint this reference is connected to.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasAccount() → Future<bool>
Returns the method value for each connected Idp subclass if the current session is authenticated and if the user has an account connected to the Idp.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited