Base endpoint for Microsoft Account-based authentication.
This endpoint exposes methods for logging in users using Microsoft authorization codes. If you would like modify the authentication flow, consider extending this class and overriding the relevant methods.
- Inheritance
-
- Object
- EndpointRef
- EndpointIdpBase
- EndpointMicrosoftIdpBase
Constructors
Properties
- caller → EndpointCaller
-
Holds a reference to the caller class.
finalinherited
- client ↔ ServerpodClientShared
-
Reference to the client.
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the endpoint this reference is connected to.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
SerializableModel> -
Stream of messages sent from an endpoint that supports streaming.
no setterinherited
Methods
-
hasAccount(
) → Future< bool> -
Returns the
methodvalue for each connectedIdpsubclass if the current session is authenticated and if the user has an account connected to theIdp.override -
login(
{required String code, required String codeVerifier, required String redirectUri, required bool isWebPlatform}) → Future< AuthSuccess> - Validates a Microsoft authorization code and either logs in the associated user or creates a new user account if the Microsoft account ID is not yet known.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetStream(
) → void -
Resets web socket stream, so it's possible to re-listen to endpoint
streams.
inherited
-
sendStreamMessage(
SerializableModel message) → Future< void> -
Sends a message to the endpoint's stream.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited