EndpointPasskeyIdpBase class abstract Endpoint

Base endpoint for Passkey-based authentication.

Inheritance

Constructors

EndpointPasskeyIdpBase(EndpointCaller caller)

Properties

caller EndpointCaller
Holds a reference to the caller class.
finalinherited
client ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the endpoint this reference is connected to.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<SerializableModel>
Stream of messages sent from an endpoint that supports streaming.
no setterinherited

Methods

createChallenge() Future<({ByteData challenge, UuidValue id})>
Returns a new challenge to be used for a login or registration request.
hasAccount() Future<bool>
Returns the method value for each connected Idp subclass if the current session is authenticated and if the user has an account connected to the Idp.
override
login({required PasskeyLoginRequest loginRequest}) Future<AuthSuccess>
Authenticates the user related to the given Passkey.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register({required PasskeyRegistrationRequest registrationRequest}) Future<void>
Registers a Passkey for the session's current user.
resetStream() → void
Resets web socket stream, so it's possible to re-listen to endpoint streams.
inherited
sendStreamMessage(SerializableModel message) Future<void>
Sends a message to the endpoint's stream.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited