hasAccount abstract method

  1. @override
Future<bool> hasAccount()
override

Returns the method value for each connected Idp subclass if the current session is authenticated and if the user has an account connected to the Idp.

Implementation

@override
_i2.Future<bool> hasAccount();