stream property
Stream<SerializableModel>
get
stream
Stream of messages sent from an endpoint that supports streaming.
Implementation
Stream<SerializableModel> get stream => _streamController.stream;
Stream of messages sent from an endpoint that supports streaming.
Stream<SerializableModel> get stream => _streamController.stream;