EndpointStatus class

Endpoint for getting status and managing a signed in user.

Inheritance

Constructors

EndpointStatus(EndpointCaller caller)

Properties

caller → EndpointCaller
Holds a reference to the caller class.
finalinherited
client ↔ ServerpodClientShared
Reference to the client.
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the endpoint this reference is connected to.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSignedIn() → Future<bool>
Returns true if the client user is signed in.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signOutAllDevices() → Future<void>
Signs out a user from all active devices.
signOutDevice() → Future<void>
Signs out a user from the current device.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited