copyWith abstract method
Returns a shallow copy of this PasskeyChallengeNotFoundException with some or all fields replaced by the given arguments.
Implementation
@_i1.useResult
PasskeyChallengeNotFoundException copyWith();
Returns a shallow copy of this PasskeyChallengeNotFoundException with some or all fields replaced by the given arguments.
@_i1.useResult
PasskeyChallengeNotFoundException copyWith();