Endpoint topic
Callable endpoints
Each class contains callable methods that will call a method on the server side. The classes are accessible via the Serverpod client you have created in your Flutter app. The name of the module is defined in your config/generator.yaml file in the server project.
modules:
<module_name>:
nickname: <nickname>
The name "EndpointClass" where Class is your class name will have the "Endpoint" part stripped when the client is code generated. When accessing you can simply use the endpoint name in lowercase.
Example usage:
// Authenticate with email.
client.modules.auth.email.authenticate(email, password)
// Generic format.
client.modules.<nickname>.<endpoint>.<method>(...)
Please see the full official documentation here
Classes
- EndpointAnonymousIdpBase Endpoint
- Base endpoint for anonymous accounts.
- EndpointAppleIdpBase Endpoint
- Endpoint for handling Sign in with Apple.
- EndpointEmailIdpBase Endpoint
- Base endpoint for email-based accounts.
- EndpointFacebookIdpBase Endpoint
- Base endpoint for Facebook Account-based authentication.
- EndpointFirebaseIdpBase Endpoint
- Base endpoint for Firebase Account-based authentication.
- EndpointGitHubIdpBase Endpoint
- Base endpoint for GitHub Account-based authentication.
- EndpointGoogleIdpBase Endpoint
- Base endpoint for Google Account-based authentication.
- EndpointIdpBase Endpoint
- Base endpoint for identity providers.
- EndpointMicrosoftIdpBase Endpoint
- Base endpoint for Microsoft Account-based authentication.
- EndpointPasskeyIdpBase Endpoint
- Base endpoint for Passkey-based authentication.
- EndpointRefreshJwtTokens
- Endpoint for JWT tokens management.
- EndpointStatus
- Endpoint for getting status and managing a signed in user.
- EndpointUserProfileEditBase
- Base endpoint for user profile management.
- EndpointUserProfileInfo
- Endpoint for read-only access to user profile information.